# scskde
Sequential Conditional Sampling from Kernel Density Estimates (SCS-KDE) is a method to fit non-parametric models to time series and generate synthetic realisations. The method implemented extends the original work in Sharma et al (1997) Streamflow simulation: A nonparametric approach [https://doi.org/10.1029/96WR02839] to include
- lag orders >= 1
- arbitrary seasonality
- vector-valued processes
- exogenous forcing
- arbitrary dependence structure
